@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Glorified metronome
 
-our $VERSION = '0.4003';
+our $VERSION = '0.4004';
 
 use strictures 2;
 use Data::Dumper::Compact qw(ddc);
@@ -472,12 +472,13 @@ sub add_fill {
 
     my $size = 4 / $lcm;
     my $dump = reverse_dump('length');
-    my $master_duration = $dump->{$size} || $self->eighth;
+    my $master_duration = $dump->{$size} || $self->eighth; # XXX this || is not right
+    print "Size: $size, Duration: $master_duration\n" if $self->verbose;
 
     my $fill_chop = $fill_duration == $lcm
         ? $fill_length
-        : int $lcm / $fill_length + 1;
-    print "FC: $fill_chop\n" if $self->verbose;
+        : int($lcm / $fill_length) + 1;
+    print "Chop: $fill_chop\n" if $self->verbose;
 
     my %fresh_patterns;
     for my $instrument (keys %patterns) {
@@ -584,7 +585,7 @@ MIDI::Drummer::Tiny - Glorified metronome
 
 =head1 VERSION
 
-version 0.4003
+version 0.4004
 
 =head1 SYNOPSIS
 
